.. _unit_test_report_utest_override_prefix:

==========================================
Unit test report for utest_override_prefix
==========================================

.. contents:: `Contents`
    :depth: 2
    :local:


.. item:: REPORT_OVERRIDING-UTEST_MY_LIB-MY_FUNCTION_SUCCESS Test report for OVERRIDING-UTEST_MY_LIB-MY_FUNCTION_SUCCESS
    :passes: OVERRIDING-UTEST_MY_LIB-MY_FUNCTION_SUCCESS

    Test result: Pass

.. item:: REPORT_OVERRIDING-UTEST_MY_LIB-TEST_MY_FUNCTION_NOT_ERASED Test report for OVERRIDING-UTEST_MY_LIB-TEST_MY_FUNCTION_NOT_ERASED
    :fails: OVERRIDING-UTEST_MY_LIB-TEST_MY_FUNCTION_NOT_ERASED

    Test result: Fail

.. item:: REPORT_OVERRIDING-UTEST_MY_LIB-TEST_MY_FUNCTION_NOT_UNLOCKED Test report for OVERRIDING-UTEST_MY_LIB-TEST_MY_FUNCTION_NOT_UNLOCKED
    :passes: OVERRIDING-UTEST_MY_LIB-TEST_MY_FUNCTION_NOT_UNLOCKED

    Test result: Pass

.. item:: REPORT_OVERRIDING-UTEST_MY_LIB-SOME_FUNCTION Test report for OVERRIDING-UTEST_MY_LIB-SOME_FUNCTION
    :fails: OVERRIDING-UTEST_MY_LIB-SOME_FUNCTION

    Test result: Fail

Traceability matrix
===================

The below table traces the test report to test cases.

.. item-matrix:: Linking these unit test reports to unit test cases
    :source: REPORT_OVERRIDING-
    :target: OVERRIDING-
    :sourcetitle: Unit test report
    :targettitle: Unit test specification
    :type: fails passes
    :stats:
    :group:
    :nocaptions:
